@@ -26,8 +26,12 @@ def register():
         CreditInvoiceStart,
         Address,
         Party,
-        FiscalYear,
+        PartyPaymentTerm,
+        InvoiceSequence,
+        # Match pattern migration fallbacks to Fiscalyear values so Period
+        # must be registered before Fiscalyear
         Period,
+        FiscalYear,
         Move,
         Reconciliation,
         module='account_invoice', type_='model')
@@ -36,6 +40,7 @@ def register():
         PrintInvoice,
         PayInvoice,
         CreditInvoice,
+        PartyReplace,
         module='account_invoice', type_='wizard')
     Pool.register(
         InvoiceReport,
